@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for Fedora 20's 3.13 kernel.
+# This is a kernel build script for Fedora 19's 3.14 kernel.
 #
 
 die () {
@@ -8,21 +8,21 @@ die () {
     exit 1
 }
 
-yum -y install tar wget rpm-build make gcc patch redhat-rpm-config xmlto asciidoc gnupg elfutils-devel zlib-devel binutils-devel newt-devel python-devel perl-ExtUtils-Embed pciutils-devel hmaccalc bison net-tools audit-libs-devel pesign bc
+yum -y install tar wget rpm-build make gcc patch redhat-rpm-config xmlto asciidoc gnupg elfutils-devel zlib-devel binutils-devel newt-devel python-devel perl-ExtUtils-Embed pciutils-devel hmaccalc bison net-tools audit-libs-devel pesign bc ncurses-devel
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-3.13.6-200.fc20.src.rpm ]
+if [ ! -r kernel-3.14.4-100.fc19.src.rpm ]
 then
-    wget http://ftp.riken.jp/Linux/fedora/updates/20/SRPMS/kernel-3.13.6-200.fc20.src.rpm || die "Can't download source package."
+    wget http://ftp.riken.jp/Linux/fedora/updates/20/SRPMS/kernel-3.14.4-100.fc19.src.rpm || die "Can't download source package."
 fi
-rpm --checksig kernel-3.13.6-200.fc20.src.rpm || die "Can't verify signature."
-rpm -ivh kernel-3.13.6-200.fc20.src.rpm || die "Can't install source package."
+rpm --checksig kernel-3.14.4-100.fc19.src.rpm || die "Can't verify signature."
+rpm -ivh kernel-3.14.4-100.fc19.src.rpm || die "Can't install source package."
 
 cd /root/rpmbuild/SOURCES/ || die "Can't chdir to /root/rpmbuild/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.3-20140401.tar.gz ]
+if [ ! -r ccs-patch-1.8.3-20140601.tar.gz ]
 then
-    wget -O ccs-patch-1.8.3-20140401.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20140401.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.3-20140601.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20140601.tar.gz' || die "Can't download patch."
 fi
 
 cd /root/rpmbuild/SPECS/ || die "Can't chdir to /root/rpmbuild/SPECS/ ."
@@ -39,9 +39,9 @@ patch << "EOF" || die "Can't patch spec file."
  ###################################################################
  
  # The buildid can also be specified on the rpmbuild command line
-@@ -437,6 +437,11 @@
- # Architectures we build tools/cpupower on
- %define cpupowerarchs %{ix86} x86_64 ppc ppc64 ppc64p7 %{arm} aarch64
+@@ -434,6 +434,11 @@
+ #
+ %define kernel_dot_org_conflicts  ppp < 2.4.3-3, isdn4k-utils < 3.2-32, nfs-utils < 1.2.5-7.fc17, e2fsprogs < 1.37-4, util-linux < 2.12, jfsutils < 1.1.7-2, reiserfs-utils < 3.6.19-2, xfsprogs < 2.6.13-4, procps < 3.2.5-6.3, oprofile < 0.9.1-2, device-mapper-libs < 1.02.63-2, mdadm < 3.2.1-5
  
 +# TOMOYO Linux
 +%define with_modsign 0
@@ -49,9 +49,9 @@ patch << "EOF" || die "Can't patch spec file."
 +%define with_debuginfo 0
 +
  #
- # Packages that need to be installed before the kernel is, because the %%post
- # scripts use them.
-@@ -477,7 +482,7 @@
+ # Then a series of requirements that are distribution specific, either
+ # because we add patches for something, or the older versions have
+@@ -490,7 +495,7 @@
  AutoProv: yes\
  %{nil}
  
@@ -60,7 +60,7 @@ patch << "EOF" || die "Can't patch spec file."
  Group: System Environment/Kernel
  License: GPLv2 and Redistributable, no modification permitted
  URL: http://www.kernel.org/
-@@ -980,7 +985,7 @@
+@@ -964,7 +969,7 @@
  AutoReqProv: no\
  Requires(pre): /usr/bin/find\
  Requires: perl\
@@ -69,27 +69,27 @@ patch << "EOF" || die "Can't patch spec file."
  This package provides kernel headers and makefiles sufficient to build modules\
  against the %{?2:%{2} }kernel package.\
  %{nil}
-@@ -1000,7 +1005,7 @@
- Provides: kernel%{?1:-%{1}}-modules-extra-uname-r = %{KVERREL}%{?1:+%{1}}\
- Requires: kernel-uname-r = %{KVERREL}%{?1:+%{1}}\
+@@ -984,7 +989,7 @@
+ Provides: kernel%{?1:-%{1}}-modules-extra-uname-r = %{KVERREL}%{?1:.%{1}}\
+ Requires: kernel-uname-r = %{KVERREL}%{?1:.%{1}}\
  AutoReqProv: no\
 -%description -n kernel%{?variant}%{?1:-%{1}}-modules-extra\
 +%description -n ccs-kernel%{?variant}%{?1:-%{1}}-modules-extra\
  This package provides less commonly used kernel modules for the %{?2:%{2} }kernel package.\
  %{nil}
  
-@@ -1546,6 +1551,10 @@
+@@ -1501,6 +1506,10 @@
  
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.8.3-20140401.tar.gz
-+patch -sp1 < patches/ccs-patch-3.13-fedora-20.diff
++tar -zxf %_sourcedir/ccs-patch-1.8.3-20140601.tar.gz
++patch -sp1 < patches/ccs-patch-3.14-fedora-19.diff
 +
  %endif
  
  # Any further pre-build tree manipulations happen here.
-@@ -1570,6 +1579,18 @@
+@@ -1523,6 +1532,18 @@
  for i in *.config
  do
    mv $i .config
